@@ -1,33 +1,17 @@
-#ifndef _LIB_RING_BUFFER_FRONTEND_TYPES_H
-#define _LIB_RING_BUFFER_FRONTEND_TYPES_H
-
-/*
+/* SPDX-License-Identifier: (GPL-2.0 OR LGPL-2.1)
+ *
  * lib/ringbuffer/frontend_types.h
  *
  * Ring Buffer Library Synchronization Header (types).
  *
  * Copyright (C) 2010-2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; only
- * version 2.1 of the License.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- * Author:
- *	Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
- *
  * See ring_buffer_frontend.c for more information on wait-free algorithms.
  */
 
+#ifndef _LIB_RING_BUFFER_FRONTEND_TYPES_H
+#define _LIB_RING_BUFFER_FRONTEND_TYPES_H
+
 #include <linux/kref.h>
 #include <wrapper/ringbuffer/config.h>
 #include <wrapper/ringbuffer/backend_types.h>
@@ -137,6 +121,20 @@ struct lib_ring_buffer {
 
 	struct commit_counters_cold *commit_cold;
 					/* Commit count per sub-buffer */
+	u64 *ts_end;			/*
+					 * timestamp_end per sub-buffer.
+					 * Time is sampled by the
+					 * switch_*_end() callbacks which
+					 * are the last space reservation
+					 * performed in the sub-buffer
+					 * before it can be fully
+					 * committed and delivered. This
+					 * time value is then read by
+					 * the deliver callback,
+					 * performed by the last commit
+					 * before the buffer becomes
+					 * readable.
+					 */
 	atomic_long_t active_readers;	/*
 					 * Active readers count
 					 * standard atomic access (shared)
