@@ -1,23 +1,10 @@
-/*
+/* SPDX-License-Identifier: (GPL-2.0 OR LGPL-2.1)
+ *
  * ring_buffer_vfs.c
  *
  * Ring Buffer VFS file operations.
  *
  * Copyright (C) 2010-2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; only
- * version 2.1 of the License.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <linux/module.h>
@@ -191,17 +178,11 @@ long lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd,
 
 	switch (cmd) {
 	case RING_BUFFER_SNAPSHOT:
-		/*
-		 * First, ensure we perform a "final" flush onto the
-		 * stream.  This will ensure we create a packet of
-		 * padding if we encounter an empty packet. This ensures
-		 * the time-stamps right before the snapshot is used as
-		 * end of packet timestamp.
-		 */
-		if (!buf->quiescent)
-			lib_ring_buffer_switch_remote_empty(buf);
 		return lib_ring_buffer_snapshot(buf, &buf->cons_snapshot,
 					    &buf->prod_snapshot);
+	case RING_BUFFER_SNAPSHOT_SAMPLE_POSITIONS:
+		return lib_ring_buffer_snapshot_sample_positions(buf,
+				&buf->cons_snapshot, &buf->prod_snapshot);
 	case RING_BUFFER_SNAPSHOT_GET_CONSUMED:
 		return put_ulong(buf->cons_snapshot, arg);
 	case RING_BUFFER_SNAPSHOT_GET_PRODUCED:
@@ -279,6 +260,9 @@ long lib_ring_buffer_ioctl(struct file *filp, unsigned int cmd,
 	case RING_BUFFER_FLUSH:
 		lib_ring_buffer_switch_remote(buf);
 		return 0;
+	case RING_BUFFER_FLUSH_EMPTY:
+		lib_ring_buffer_switch_remote_empty(buf);
+		return 0;
 	default:
 		return -ENOIOCTLCMD;
 	}
@@ -329,17 +313,11 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 
 	switch (cmd) {
 	case RING_BUFFER_COMPAT_SNAPSHOT:
-		/*
-		 * First, ensure we perform a "final" flush onto the
-		 * stream.  This will ensure we create a packet of
-		 * padding if we encounter an empty packet. This ensures
-		 * the time-stamps right before the snapshot is used as
-		 * end of packet timestamp.
-		 */
-		if (!buf->quiescent)
-			lib_ring_buffer_switch_remote_empty(buf);
 		return lib_ring_buffer_snapshot(buf, &buf->cons_snapshot,
 						&buf->prod_snapshot);
+	case RING_BUFFER_COMPAT_SNAPSHOT_SAMPLE_POSITIONS:
+		return lib_ring_buffer_snapshot_sample_positions(buf,
+				&buf->cons_snapshot, &buf->prod_snapshot);
 	case RING_BUFFER_COMPAT_SNAPSHOT_GET_CONSUMED:
 		return compat_put_ulong(buf->cons_snapshot, arg);
 	case RING_BUFFER_COMPAT_SNAPSHOT_GET_PRODUCED:
@@ -433,6 +411,9 @@ long lib_ring_buffer_compat_ioctl(struct file *filp, unsigned int cmd,
 	case RING_BUFFER_COMPAT_FLUSH:
 		lib_ring_buffer_switch_remote(buf);
 		return 0;
+	case RING_BUFFER_COMPAT_FLUSH_EMPTY:
+		lib_ring_buffer_switch_remote_empty(buf);
+		return 0;
 	default:
 		return -ENOIOCTLCMD;
 	}
@@ -465,8 +446,8 @@ const struct file_operations lib_ring_buffer_file_operations = {
 EXPORT_SYMBOL_GPL(lib_ring_buffer_file_operations);
 
 MODULE_LICENSE("GPL and additional rights");
-MODULE_AUTHOR("Mathieu Desnoyers");
-MODULE_DESCRIPTION("Ring Buffer Library VFS");
+MODULE_AUTHOR("Mathieu Desnoyers <mathieu.desnoyers@efficios.com>");
+MODULE_DESCRIPTION("LTTng ring buffer library");
 MODULE_VERSION(__stringify(LTTNG_MODULES_MAJOR_VERSION) "."
 	__stringify(LTTNG_MODULES_MINOR_VERSION) "."
 	__stringify(LTTNG_MODULES_PATCHLEVEL_VERSION)
