@@ -73,6 +73,18 @@ struct mmap_arg_struct;
 struct file_handle;
 struct user_msghdr;
 
+/*
+ * Forward declaration for kernels >= 5.6
+ */
+struct timex;
+struct timeval;
+struct itimerval;
+struct itimerspec;
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
+typedef __kernel_old_time_t time_t;
+#endif
+
 #ifdef IA32_NR_syscalls
 #define NR_compat_syscalls IA32_NR_syscalls
 #else
@@ -905,15 +917,15 @@ int lttng_syscalls_unregister(struct lttng_channel *chan)
 	if (!chan->sc_table)
 		return 0;
 	if (chan->sys_enter_registered) {
-		ret = lttng_wrapper_tracepoint_probe_unregister("sys_exit",
-				(void *) syscall_exit_probe, chan);
+		ret = lttng_wrapper_tracepoint_probe_unregister("sys_enter",
+				(void *) syscall_entry_probe, chan);
 		if (ret)
 			return ret;
 		chan->sys_enter_registered = 0;
 	}
 	if (chan->sys_exit_registered) {
-		ret = lttng_wrapper_tracepoint_probe_unregister("sys_enter",
-				(void *) syscall_entry_probe, chan);
+		ret = lttng_wrapper_tracepoint_probe_unregister("sys_exit",
+				(void *) syscall_exit_probe, chan);
 		if (ret)
 			return ret;
 		chan->sys_exit_registered = 0;
