@@ -1,29 +1,16 @@
-/*
+/* SPDX-License-Identifier: (GPL-2.0 or LGPL-2.1)
+ *
  * probes/lttng-probe-kvm.c
  *
  * LTTng kvm probes.
  *
  * Copyright (C) 2010-2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; only
- * version 2.1 of the License.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <linux/module.h>
 #include <linux/kvm_host.h>
-#include "../lttng-tracer.h"
-#include "../lttng-kernel-version.h"
+#include <lttng-tracer.h>
+#include <lttng-kernel-version.h>
 
 #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,1,0))
 #include <kvm/iodev.h>
@@ -35,7 +22,7 @@
  * Create the tracepoint static inlines from the kernel to validate that our
  * trace event macros match the kernel we run on.
  */
-#include "../wrapper/tracepoint.h"
+#include <wrapper/tracepoint.h>
 
 #include <../../arch/x86/kvm/mmutrace.h>
 
@@ -48,8 +35,8 @@
 #define LTTNG_PACKAGE_BUILD
 #define CREATE_TRACE_POINTS
 
-#define TRACE_INCLUDE_PATH ../instrumentation/events/lttng-module/arch/x86/kvm
-#include "../instrumentation/events/lttng-module/arch/x86/kvm/mmutrace.h"
+#define TRACE_INCLUDE_PATH instrumentation/events/lttng-module/arch/x86/kvm
+#include <instrumentation/events/lttng-module/arch/x86/kvm/mmutrace.h>
 
 MODULE_LICENSE("GPL and additional rights");
 MODULE_AUTHOR("Mathieu Desnoyers <mathieu.desnoyers@efficios.com>");
